==> fusenshi-0.7.2.tgz: fusenshi-0.7.2/src/wnd/fusenshimainwndeventprocessor.cpp <==
/*
 * $Id: fusenshimainwndeventprocessor.cpp,v 1.1 2005/02/04 17:07:41 ozawa Exp $
 *
 * Copyright 2004- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.1 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include "../include/fusenshi.h"
#include "fusenshimainwndeventprocessor.h"
#include "fusenshimainwnd.h"
#include "wndservice.h"
#include "propertydialog.h"

/**
 * 󥹥ȥ饯
 */
FusenshiMainWndEventProcessor::FusenshiMainWndEventProcessor()
{
    m_bShowAll = true;
}

/**
 * ǥȥ饯
 */
FusenshiMainWndEventProcessor::~FusenshiMainWndEventProcessor()
{
}

/**
 * ޥܥ󲡲
 */
bool FusenshiMainWndEventProcessor::on_button_press_event(GdkEventButton* pEvent)
{
    if (pEvent->type != GDK_BUTTON_PRESS) {
        return false;
    }
    
    // å˱䵻򿷵˺
    if (pEvent->button == 1) {
        // 䵻ο
        WndService::getInstance()->createFusenshi();
    }
    // å˱ơݥåץåץ˥塼ɽ
    else if (pEvent->button == 3) {
    	int count = 0;
        Gtk::Menu* pMenu = manage(new Gtk::Menu());

#define MENU_NUMBER     5
	    Glib::ustring pMenuLabels[MENU_NUMBER] = {
            Glib::ustring(_("Raise windows")),
            Glib::ustring(_("Hide windows")),
            Glib::ustring(_("Refresh windows")),
	    	Glib::ustring(_("Property")),
	    	Glib::ustring(_("Quit"))
	    };
	    sigc::slot<void> slots[MENU_NUMBER] = {
            sigc::mem_fun(*this, &FusenshiMainWndEventProcessor::on_menu_raise_windows),
            sigc::mem_fun(*this, &FusenshiMainWndEventProcessor::on_menu_show_hide_windows),
            sigc::mem_fun(*this, &FusenshiMainWndEventProcessor::on_menu_refresh_windows),
	        sigc::mem_fun(*this, &FusenshiMainWndEventProcessor::on_menu_property_activate),
	        sigc::mem_fun(*this, &FusenshiMainWndEventProcessor::on_menu_close_activate)
	    };
        const int sepPos[] = {
            3, 2, 0 // ߽ǻꤹ
        };
	    
        // ֤˲碌ƥƥѹ
        if (!m_bShowAll) {
            pMenuLabels[1] = _("Show windows");
        }
        
	    // ƥ
	    Gtk::MenuItem* pMenuItem = NULL;
	    for (count = 0; count < MENU_NUMBER; count++) {
	        pMenuItem = manage(new Gtk::MenuItem(pMenuLabels[count]));
	        
	        pMenu->append(*pMenuItem);
	        
	        pMenuItem->signal_activate().connect(slots[count]);
	        pMenuItem->show();
	    }
#undef MENU_NUMBER

        // ѥ졼ɲ
        for (count = 0; 0 < sepPos[count]; count++) {
            pMenuItem = manage(new Gtk::MenuItem());
    
            pMenu->insert(*pMenuItem, sepPos[count]);
            pMenuItem->show();
        }
        
        pMenu->show();
        pMenu->popup(pEvent->button, pEvent->time);
    }
    
    return false;
}

/**
 * ݥåץåץ˥塼Ρֺ̤ɽפα
 */
void FusenshiMainWndEventProcessor::on_menu_raise_windows()
{
    WndService::getInstance()->raiseFusenshiWndAll();
}

/**
 * ݥåץåץ˥塼Ρɽɽפα
 */
void FusenshiMainWndEventProcessor::on_menu_show_hide_windows()
{
    if (m_bShowAll) {
        WndService::getInstance()->hideFusenshiWndAll();
        m_bShowAll = false;
    }
    else {
        WndService::getInstance()->showFusenshiWndAll();
        m_bShowAll = true;
    }
}

/**
 * ݥåץåץ˥塼Ρֺפα
 */
void FusenshiMainWndEventProcessor::on_menu_refresh_windows()
{
    WndService::getInstance()->refreshFusenshiWndAll();
}

/**
 * ݥåץåץ˥塼Ρפα
 */
void FusenshiMainWndEventProcessor::on_menu_property_activate()
{
    PropertyDialog dlg(PropertyData::get());

    if (Gtk::RESPONSE_OK == dlg.doModal()) {
        WndService* pInstance = WndService::getInstance();
        
        PropertyData::set(dlg.getNewData());    // ѹݻ
        pInstance->noticeProperty();            // I/O
        pInstance->updateProperty();            // ɥ򹹿
    }
}

/**
 * ݥåץåץ˥塼ΡĤפα
 */
void FusenshiMainWndEventProcessor::on_menu_close_activate()
{
    // 䵻楦ɥ˴
    WndService::getInstance()->destroyFusenshiWndAll();
    
    // ɥλ롣
    WndService::getInstance()->stop();
}

==> fusenshi-0.7.3.tgz: fusenshi-0.7.3/src/wnd/fusenshimainwndeventprocessor.cpp <==
/*
 * $Id: fusenshimainwndeventprocessor.cpp,v 1.4 2005/04/13 08:37:06 ozawa Exp $
 *
 * Copyright 2004- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.4 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#include "../include/fusenshi.h"
#include "fusenshimainwndeventprocessor.h"
#include "fusenshimainwnd.h"
#include "menubuilder.h"
#include "wndservice.h"
#include "propertydialog.h"

/**
 * 󥹥ȥ饯
 */
FusenshiMainWndEventProcessor::FusenshiMainWndEventProcessor()
{
}

/**
 * ǥȥ饯
 */
FusenshiMainWndEventProcessor::~FusenshiMainWndEventProcessor()
{
}

/**
 * ݥåץåץ˥塼ۡޤ
 */
bool FusenshiMainWndEventProcessor::buildPopupMenu()
{
#define MENU_ROOT_PATH   "<" APP_NAME ">/FusenshiMainWnd/PopupMenu"
    // ˥塼
    if (!m_bPopupMenuBuildFlag) {
        sigc::slot<void> slots[] = {
            sigc::mem_fun(*this, &FusenshiMainWndEventProcessor::on_menu_raise_windows),
            sigc::mem_fun(*this, &FusenshiMainWndEventProcessor::on_menu_show_hide_windows),
            sigc::mem_fun(*this, &FusenshiMainWndEventProcessor::on_menu_refresh_windows),
            sigc::mem_fun(*this, &FusenshiMainWndEventProcessor::on_menu_property_activate),
            sigc::mem_fun(*this, &FusenshiMainWndEventProcessor::on_menu_close_activate)
        };
        const MenuTable menutable[] = {
            {TYPE_MENUITEM,  "/RAISE",     _("_Raise all"),  NULL, &slots[0], &menutable[1], NULL},
            {TYPE_MENUITEM,  "/SHOW_HIDE", "show/hide",          NULL, &slots[1], &menutable[2], NULL},
            {TYPE_SEPARATOR, "/SEP1",      NULL,                 NULL, NULL,      &menutable[3], NULL},
            {TYPE_MENUITEM,  "/REFRESH",   _("Re_draw all"), NULL, &slots[2], &menutable[4], NULL},
            {TYPE_SEPARATOR, "/SEP2",      NULL,                 NULL, NULL,      &menutable[5], NULL},
            {TYPE_MENUITEM,  "/PROPERTY",  _("_Property"),       NULL, &slots[3], &menutable[6], NULL},
            {TYPE_MENUITEM,  "/QUIT",      _("_Quit"),           NULL, &slots[4], NULL,          NULL}
        };

        // ˥塼
        if (!MenuBuilder::rebuildMenu(m_cPopupMenu, menutable[0], MENU_ROOT_PATH)) {
            // ۼ
            fprintf(stderr, "%s: Unable to build popup menu for 'FusenshiMainWnd'.\n", APP_NAME);
            return false;
        }
        
        m_bPopupMenuBuildFlag = true;
    }
    
    // ֤ˤ碌ƥ˥塼٥ѹ
    Gtk::MenuItem *pItem =
        MenuBuilder::findMenuItem(m_cPopupMenu, MENU_ROOT_PATH "/SHOW_HIDE");
    if (pItem) {
        ((Gtk::Label*)pItem->get_child())->set_label
            (WndService::getInstance()->isShowFusenshiWndAll() ?
             _("_Hide all") : _("_Show all"));
    }
    
    return true;
}

/**
 * ݥåץåץ˥塼ɽޤ
 */
void FusenshiMainWndEventProcessor::showPopupMenu(GdkEventButton* pEvent)
{
    if (buildPopupMenu()) {
        m_cPopupMenu.popup(pEvent->button, pEvent->time);
    }
}

/**
 * ޥܥ󲡲
 */
bool FusenshiMainWndEventProcessor::on_button_press_event(GdkEventButton* pEvent)
{
    if (pEvent->type != GDK_BUTTON_PRESS) {
        return false;
    }
    
    // å˱䵻򿷵˺
    if (pEvent->button == 1) {
        // 䵻ο
        WndService::getInstance()->createFusenshi();
    }
    // å˱ơݥåץåץ˥塼ɽ
    else if (pEvent->button == 3) {
        showPopupMenu(pEvent);
        
        return true;
    }
    
    return false;
}

/**
 * ݥåץåץ˥塼Ρֺ̤ɽפα
 */
void FusenshiMainWndEventProcessor::on_menu_raise_windows()
{
    WndService::getInstance()->raiseFusenshiWndAll();
}

/**
 * ݥåץåץ˥塼Ρɽɽפα
 */
void FusenshiMainWndEventProcessor::on_menu_show_hide_windows()
{
    if (WndService::getInstance()->isShowFusenshiWndAll()) {
        WndService::getInstance()->hideFusenshiWndAll();
    }
    else {
        WndService::getInstance()->showFusenshiWndAll();
    }
}

/**
 * ݥåץåץ˥塼Ρֺפα
 */
void FusenshiMainWndEventProcessor::on_menu_refresh_windows()
{
    WndService::getInstance()->refreshFusenshiWndAll();
}

/**
 * ݥåץåץ˥塼Ρפα
 */
void FusenshiMainWndEventProcessor::on_menu_property_activate()
{
    PropertyDialog dlg(PropertyData::get());

    if (Gtk::RESPONSE_OK == dlg.doModal()) {
        WndService* pInstance = WndService::getInstance();
        
        PropertyData::set(dlg.getNewData());    // ѹݻ
        pInstance->noticeProperty();            // I/O
        pInstance->updateProperty();            // ɥ򹹿
    }
}

/**
 * ݥåץåץ˥塼ΡĤפα
 */
void FusenshiMainWndEventProcessor::on_menu_close_activate()
{
    // 䵻楦ɥ˴
    WndService::getInstance()->destroyFusenshiWndAll();
    
    // ɥλ롣
    WndService::getInstance()->stop();
}
